#!/usr/local/bin/pvmsh1.1

package require Pvm 1.1

set result ""
set parent [parent]

proc bgerror {msg} {
    global parent result
    send $parent 0 "Error in slave: \"$msg\"\nreceived so far: \"$result\""
}

bind $parent 1 {
    set type [recv string]
    set result "$type [eval recv $type]"
    pvm send $parent 0 -string $result
}

pvm bind $parent kill exit

pvm send $parent 0 -string "slave started"
